@@ -1,7 +1,7 @@
 GPmap <-
 function (obj) 
 {
-    if (class(obj) == "noia.linear") {
+    if (inherits(obj, "noia.linear")) {
         if (is.null(obj$smat)) {
             stop("No GP map estimate with 'fast' algorith")
         }
@@ -11,7 +11,7 @@ function (obj)
         class(g) <- c("noia.gpmap", class(g))
         return(g)
     }
-    else if (class(obj) == "noia.multilinear") {
+    else if (inherits(obj, "noia.multilinear")) {
         rec <- reconstructLinearEffects(obj)
         g <- cbind(obj$smat %*% rec[, 1], sqrt((obj$smat * obj$smat) %*% 
             (rec[, 2] * rec[, 2])))
