@@ -1,16 +1,16 @@
 effectsVariances <-
 function (obj) 
 {
-    if ((class(obj) != "noia.linear") && (class(obj) != "noia.linear.gpmap")) {
+    if (!inherits(obj,"noia.linear") && !inherits(obj, "noia.linear.gpmap")) {
         stop("Unexpected object of class \"", class(obj), "\"\n")
     }
     v <- NULL
-    if ((class(obj) == "noia.linear" && is.null(obj$zmat)) || 
+    if (inherits(obj, "noia.linear") && is.null(obj$zmat) || 
         is.null(obj$smat)) {
         v <- rep(NA, length(obj$E))
     }
     else {
-        if (class(obj) == "noia.linear") {
+        if (inherits(obj, "noia.linear")) {
             freq <- Z2freq(obj$zmat)
         }
         else {
