@@ -1,4 +1,4 @@
-`print.noia.linear` <-
+print.noia.linear <-
 function (x, ...) 
 {
     print.noia.common(x, ...)
